pub async unsafe fn async_drop_in_place<T>(_to_drop: *mut T)where
T: ?Sized,🔬This is a nightly-only experimental API. (
async_drop)Expand description
Async drop.
Safety
The pointer _to_drop must be valid for both reads and writes,
not only for the duration of this function call,
but also until the returned future has completed.
See ptr::drop_in_place for additional safety concerns.