Sync

Trait Sync 

1.0.0 · Source
pub unsafe auto trait Sync { }
Types for which it is safe to share references between threads.

This trait is automatically implemented when the compiler determines it’s appropriate.

The precise definition is: a type T is Sync if and only if &T is Send. In other words, if there is no possibility of undefined behavior (including data races) when passing &T references between threads.

As one would expect, primitive types like u8 and f64 are all Sync, and so are simple aggregate types containing them, like tuples, structs and enums. More examples of basic Sync types include “immutable” types like &T, and those with simple inherited mutability, such as Box<T>, Vec<T> and most other collection types. (Generic parameters need to be Sync for their container to be Sync.)

A somewhat surprising consequence of the definition is that &mut T is Sync (if T is Sync) even though it seems like that might provide unsynchronized mutation. The trick is that a mutable reference behind a shared reference (that is, & &mut T) becomes read-only, as if it were a & &T. Hence there is no risk of a data race.

A shorter overview of how Sync and Send relate to referencing:

  • &T is Send if and only if T is Sync
  • &mut T is Send if and only if T is Send
  • &T and &mut T are Sync if and only if T is Sync

Types that are not Sync are those that have “interior mutability” in a non-thread-safe form, such as Cell and RefCell. These types allow for mutation of their contents even through an immutable, shared reference. For example the set method on Cell<T> takes &self, so it requires only a shared reference &Cell<T>. The method performs no synchronization, thus Cell cannot be Sync.

Another example of a non-Sync type is the reference-counting pointer Rc. Given any reference &Rc<T>, you can clone a new Rc<T>, modifying the reference counts in a non-atomic way.

For cases when one does need thread-safe interior mutability, Rust provides atomic data types, as well as explicit locking via sync::Mutex and sync::RwLock. These types ensure that any mutation cannot cause data races, hence the types are Sync. Likewise, sync::Arc provides a thread-safe analogue of Rc.

Any types with interior mutability must also use the cell::UnsafeCell wrapper around the value(s) which can be mutated through a shared reference. Failing to doing this is undefined behavior. For example, transmute-ing from &T to &mut T is invalid.

See the Nomicon for more details about Sync.

Implementors

1.0.0 · Source

impl !Sync for Arguments<'_>

Source

impl !Sync for LocalWaker

1.0.0 · Source

impl<T> !Sync for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> !Sync for *mut T
where T: ?Sized,

1.0.0 · Source

impl<T> !Sync for Cell<T>
where T: ?Sized,

1.70.0 · Source

impl<T> !Sync for OnceCell<T>

1.0.0 · Source

impl<T> !Sync for RefCell<T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Sync for UnsafeCell<T>
where T: ?Sized,

1.25.0 · Source

impl<T> !Sync for NonNull<T>
where T: ?Sized,

NonNull pointers are not Sync because the data they reference may be aliased.

1.0.0 · Source

impl Sync for TypeId

Source

impl Sync for maybe_std::ffi::c_str::Bytes<'_>

1.10.0 · Source

impl Sync for Location<'_>

1.36.0 · Source

impl Sync for Waker

Source

impl<Dyn> Sync for DynMetadata<Dyn>
where Dyn: ?Sized,

Source

impl<T> Sync for SyncUnsafeCell<T>
where T: Sync + ?Sized,

1.28.0 · Source

impl<T> Sync for NonZero<T>

Source

impl<T> Sync for UnsafePinned<T>
where T: Sync + ?Sized,

1.31.0 · Source

impl<T> Sync for ChunksExactMut<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for ChunksMut<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for maybe_std::slice::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for maybe_std::slice::IterMut<'_, T>
where T: Sync,

1.31.0 · Source

impl<T> Sync for RChunksExactMut<'_, T>
where T: Sync,

1.31.0 · Source

impl<T> Sync for RChunksMut<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for Atomic<T>
where T: AtomicPrimitive,

Source

impl<T> Sync for Exclusive<T>
where T: ?Sized,

Source

impl<T, const VARIANT: u32, const FIELD: u32> Sync for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,

Auto implementors



impl !Sync for RawWaker



impl<'a> !Sync for Request<'a>



impl<'a> !Sync for Source<'a>



impl<'a> !Sync for VaList<'a>



impl<'a> !Sync for Formatter<'a>



impl<'a> !Sync for PanicInfo<'a>



impl<'a> !Sync for PanicMessage<'a>



impl<'a> !Sync for Context<'a>



impl<'a> !Sync for ContextBuilder<'a>



impl<'a, 'b> !Sync for DebugList<'a, 'b>



impl<'a, 'b> !Sync for DebugMap<'a, 'b>



impl<'a, 'b> !Sync for DebugSet<'a, 'b>



impl<'a, 'b> !Sync for DebugStruct<'a, 'b>



impl<'a, 'b> !Sync for DebugTuple<'a, 'b>



impl<'b, T> !Sync for Ref<'b, T>



impl<'b, T> !Sync for RefMut<'b, T>



impl<T, F = fn() -> T> !Sync for LazyCell<T, F>



impl Sync for AsciiChar



impl Sync for maybe_std::cmp::Ordering



impl Sync for Infallible



impl Sync for FromBytesWithNulError



impl Sync for c_void



impl Sync for maybe_std::fmt::Alignment



impl Sync for DebugAsHex



impl Sync for maybe_std::fmt::Sign



impl Sync for Locality



impl Sync for AtomicOrdering



impl Sync for BasicBlock



impl Sync for UnwindTerminateReason



impl Sync for SimdAlign



impl Sync for Abi



impl Sync for Generic



impl Sync for TypeKind



impl Sync for IpAddr



impl Sync for Ipv6MulticastScope



impl Sync for SocketAddr



impl Sync for FpCategory



impl Sync for IntErrorKind



impl Sync for OneSidedRangeBound



impl Sync for GetDisjointMutError



impl Sync for SearchStep



impl Sync for maybe_std::sync::atomic::Ordering



impl Sync for AllocError



impl Sync for Layout



impl Sync for LayoutError



impl Sync for ISH



impl Sync for ISHLD



impl Sync for ISHST



impl Sync for LD



impl Sync for NSH



impl Sync for NSHLD



impl Sync for NSHST



impl Sync for OSH



impl Sync for OSHLD



impl Sync for OSHST



impl Sync for ST



impl Sync for SY



impl Sync for float16x4_t



impl Sync for float16x4x2_t



impl Sync for float16x4x3_t



impl Sync for float16x4x4_t



impl Sync for float16x8_t



impl Sync for float16x8x2_t



impl Sync for float16x8x3_t



impl Sync for float16x8x4_t



impl Sync for float32x2_t



impl Sync for float32x2x2_t



impl Sync for float32x2x3_t



impl Sync for float32x2x4_t



impl Sync for float32x4_t



impl Sync for float32x4x2_t



impl Sync for float32x4x3_t



impl Sync for float32x4x4_t



impl Sync for float64x1_t



impl Sync for float64x1x2_t



impl Sync for float64x1x3_t



impl Sync for float64x1x4_t



impl Sync for float64x2_t



impl Sync for float64x2x2_t



impl Sync for float64x2x3_t



impl Sync for float64x2x4_t



impl Sync for int8x8_t



impl Sync for int8x8x2_t



impl Sync for int8x8x3_t



impl Sync for int8x8x4_t



impl Sync for int8x16_t



impl Sync for int8x16x2_t



impl Sync for int8x16x3_t



impl Sync for int8x16x4_t



impl Sync for int16x4_t



impl Sync for int16x4x2_t



impl Sync for int16x4x3_t



impl Sync for int16x4x4_t



impl Sync for int16x8_t



impl Sync for int16x8x2_t



impl Sync for int16x8x3_t



impl Sync for int16x8x4_t



impl Sync for int32x2_t



impl Sync for int32x2x2_t



impl Sync for int32x2x3_t



impl Sync for int32x2x4_t



impl Sync for int32x4_t



impl Sync for int32x4x2_t



impl Sync for int32x4x3_t



impl Sync for int32x4x4_t



impl Sync for int64x1_t



impl Sync for int64x1x2_t



impl Sync for int64x1x3_t



impl Sync for int64x1x4_t



impl Sync for int64x2_t



impl Sync for int64x2x2_t



impl Sync for int64x2x3_t



impl Sync for int64x2x4_t



impl Sync for poly8x8_t



impl Sync for poly8x8x2_t



impl Sync for poly8x8x3_t



impl Sync for poly8x8x4_t



impl Sync for poly8x16_t



impl Sync for poly8x16x2_t



impl Sync for poly8x16x3_t



impl Sync for poly8x16x4_t



impl Sync for poly16x4_t



impl Sync for poly16x4x2_t



impl Sync for poly16x4x3_t



impl Sync for poly16x4x4_t



impl Sync for poly16x8_t



impl Sync for poly16x8x2_t



impl Sync for poly16x8x3_t



impl Sync for poly16x8x4_t



impl Sync for poly64x1_t



impl Sync for poly64x1x2_t



impl Sync for poly64x1x3_t



impl Sync for poly64x1x4_t



impl Sync for poly64x2_t



impl Sync for poly64x2x2_t



impl Sync for poly64x2x3_t



impl Sync for poly64x2x4_t



impl Sync for uint8x8_t



impl Sync for uint8x8x2_t



impl Sync for uint8x8x3_t



impl Sync for uint8x8x4_t



impl Sync for uint8x16_t



impl Sync for uint8x16x2_t



impl Sync for uint8x16x3_t



impl Sync for uint8x16x4_t



impl Sync for uint16x4_t



impl Sync for uint16x4x2_t



impl Sync for uint16x4x3_t



impl Sync for uint16x4x4_t



impl Sync for uint16x8_t



impl Sync for uint16x8x2_t



impl Sync for uint16x8x3_t



impl Sync for uint16x8x4_t



impl Sync for uint32x2_t



impl Sync for uint32x2x2_t



impl Sync for uint32x2x3_t



impl Sync for uint32x2x4_t



impl Sync for uint32x4_t



impl Sync for uint32x4x2_t



impl Sync for uint32x4x3_t



impl Sync for uint32x4x4_t



impl Sync for uint64x1_t



impl Sync for uint64x1x2_t



impl Sync for uint64x1x3_t



impl Sync for uint64x1x4_t



impl Sync for uint64x2_t



impl Sync for uint64x2x2_t



impl Sync for uint64x2x3_t



impl Sync for uint64x2x4_t



impl Sync for TryFromSliceError



impl Sync for maybe_std::ascii::EscapeDefault



impl Sync for ByteStr



impl Sync for BorrowError



impl Sync for BorrowMutError



impl Sync for CharTryFromError



impl Sync for DecodeUtf16Error



impl Sync for maybe_std::char::EscapeDebug



impl Sync for maybe_std::char::EscapeDefault



impl Sync for maybe_std::char::EscapeUnicode



impl Sync for ParseCharError



impl Sync for ToLowercase



impl Sync for ToUppercase



impl Sync for TryFromCharError



impl Sync for CStr



impl Sync for FromBytesUntilNulError



impl Sync for Error



impl Sync for FormattingOptions



impl Sync for SipHasher



impl Sync for Last



impl Sync for ReturnToArg



impl Sync for UnwindActionArg



impl Sync for Assume



impl Sync for Array



impl Sync for Bool



impl Sync for Char



impl Sync for Const



impl Sync for DynTrait



impl Sync for DynTraitPredicate



impl Sync for Enum



impl Sync for Field



impl Sync for Float



impl Sync for FnPtr



impl Sync for GenericType



impl Sync for Int



impl Sync for Lifetime



impl Sync for Pointer



impl Sync for Reference



impl Sync for Slice



impl Sync for Str



impl Sync for Struct



impl Sync for Trait



impl Sync for Tuple



impl Sync for Type



impl Sync for Union



impl Sync for Variant



impl Sync for AddrParseError



impl Sync for Ipv4Addr



impl Sync for Ipv6Addr



impl Sync for SocketAddrV4



impl Sync for SocketAddrV6



impl Sync for ParseFloatError



impl Sync for ParseIntError



impl Sync for TryFromIntError



impl Sync for RangeFull



impl Sync for maybe_std::ptr::Alignment



impl Sync for ParseBoolError



impl Sync for Utf8Error



impl Sync for RawWakerVTable



impl Sync for Duration



impl Sync for TryFromFloatSecsError



impl Sync for PhantomPinned



impl Sync for Big8x3



impl Sync for Big32x40



impl Sync for CodePointInner



impl Sync for Decimal



impl Sync for DecimalSeq



impl Sync for Decoded



impl Sync for FullDecoded



impl Sync for I32NotAllOnes



impl Sync for I64NotAllOnes



impl Sync for Nanoseconds



impl Sync for NonZeroCharInner



impl Sync for NonZeroI8Inner



impl Sync for NonZeroI16Inner



impl Sync for NonZeroI32Inner



impl Sync for NonZeroI64Inner



impl Sync for NonZeroI128Inner



impl Sync for NonZeroIsizeInner



impl Sync for NonZeroU8Inner



impl Sync for NonZeroU16Inner



impl Sync for NonZeroU32Inner



impl Sync for NonZeroU64Inner



impl Sync for NonZeroU128Inner



impl Sync for NonZeroUsizeInner



impl Sync for Sign



impl Sync for U32NotAllOnes



impl Sync for U64NotAllOnes



impl Sync for UsizeNoHighBit



impl<'a> Sync for Utf8Pattern<'a>



impl<'a> Sync for BorrowedCursor<'a>



impl<'a> Sync for EscapeAscii<'a>



impl<'a> Sync for CharSearcher<'a>



impl<'a> Sync for maybe_std::str::Bytes<'a>



impl<'a> Sync for CharIndices<'a>



impl<'a> Sync for Chars<'a>



impl<'a> Sync for EncodeUtf16<'a>



impl<'a> Sync for maybe_std::str::EscapeDebug<'a>



impl<'a> Sync for maybe_std::str::EscapeDefault<'a>



impl<'a> Sync for maybe_std::str::EscapeUnicode<'a>



impl<'a> Sync for Lines<'a>



impl<'a> Sync for LinesAny<'a>



impl<'a> Sync for SplitAsciiWhitespace<'a>



impl<'a> Sync for SplitWhitespace<'a>



impl<'a> Sync for Utf8Chunk<'a>



impl<'a> Sync for Utf8Chunks<'a>



impl<'a> Sync for PhantomContravariantLifetime<'a>



impl<'a> Sync for PhantomCovariantLifetime<'a>



impl<'a> Sync for PhantomInvariantLifetime<'a>



impl<'a> Sync for Formatted<'a>



impl<'a> Sync for Part<'a>



impl<'a, 'b> Sync for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Sync for StrSearcher<'a, 'b>



impl<'a, 'b, const N: usize> Sync for CharArrayRefSearcher<'a, 'b, N>



impl<'a, A> Sync for maybe_std::option::Iter<'a, A>
where A: Sync,



impl<'a, A> Sync for maybe_std::option::IterMut<'a, A>
where A: Sync,



impl<'a, F> Sync for CharPredicateSearcher<'a, F>
where F: Sync,



impl<'a, I> Sync for ByRefSized<'a, I>
where I: Sync,



impl<'a, P> Sync for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for maybe_std::str::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for maybe_std::str::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for maybe_std::str::Split<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for maybe_std::str::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for maybe_std::str::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, T> Sync for maybe_std::result::Iter<'a, T>
where T: Sync,



impl<'a, T> Sync for maybe_std::result::IterMut<'a, T>
where T: Sync,



impl<'a, T> Sync for Chunks<'a, T>
where T: Sync,



impl<'a, T> Sync for ChunksExact<'a, T>
where T: Sync,



impl<'a, T> Sync for RChunks<'a, T>
where T: Sync,



impl<'a, T> Sync for RChunksExact<'a, T>
where T: Sync,



impl<'a, T> Sync for Windows<'a, T>
where T: Sync,



impl<'a, T, P> Sync for ChunkBy<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for ChunkByMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for maybe_std::slice::RSplit<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for RSplitMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for maybe_std::slice::RSplitN<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for RSplitNMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for maybe_std::slice::Split<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for maybe_std::slice::SplitInclusive<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitInclusiveMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for maybe_std::slice::SplitN<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitNMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, const N: usize> Sync for ArrayWindows<'a, T, N>
where T: Sync,



impl<'a, const N: usize> Sync for CharArraySearcher<'a, N>



impl<'data> Sync for BorrowedBuf<'data>



impl<A> Sync for Repeat<A>
where A: Sync,



impl<A> Sync for RepeatN<A>
where A: Sync,



impl<A> Sync for maybe_std::option::IntoIter<A>
where A: Sync,



impl<A> Sync for OptionFlatten<A>
where A: Sync,



impl<A> Sync for RangeFromIter<A>
where A: Sync,



impl<A> Sync for RangeInclusiveIter<A>
where A: Sync,



impl<A> Sync for RangeIter<A>
where A: Sync,



impl<A, B> Sync for Chain<A, B>
where A: Sync, B: Sync,



impl<A, B> Sync for Zip<A, B>
where A: Sync, B: Sync,



impl<B, C> Sync for ControlFlow<B, C>
where C: Sync, B: Sync,



impl<F> Sync for maybe_std::fmt::FromFn<F>
where F: Sync,



impl<F> Sync for PollFn<F>
where F: Sync,



impl<F> Sync for maybe_std::iter::FromFn<F>
where F: Sync,



impl<F> Sync for OnceWith<F>
where F: Sync,



impl<F> Sync for RepeatWith<F>
where F: Sync,



impl<G> Sync for FromCoroutine<G>
where G: Sync,



impl<H> Sync for BuildHasherDefault<H>



impl<I> Sync for FromIter<I>
where I: Sync,



impl<I> Sync for DecodeUtf16<I>
where I: Sync,



impl<I> Sync for Cloned<I>
where I: Sync,



impl<I> Sync for Copied<I>
where I: Sync,



impl<I> Sync for Cycle<I>
where I: Sync,



impl<I> Sync for Enumerate<I>
where I: Sync,



impl<I> Sync for Flatten<I>
where <<I as Iterator>::Item as IntoIterator>::IntoIter: Sync, I: Sync,



impl<I> Sync for Fuse<I>
where I: Sync,



impl<I> Sync for Intersperse<I>
where <I as Iterator>::Item: Sized + Sync, I: Sync,



impl<I> Sync for Peekable<I>
where I: Sync, <I as Iterator>::Item: Sync,



impl<I> Sync for Skip<I>
where I: Sync,



impl<I> Sync for StepBy<I>
where I: Sync,



impl<I> Sync for Take<I>
where I: Sync,



impl<I, F> Sync for FilterMap<I, F>
where I: Sync, F: Sync,



impl<I, F> Sync for Inspect<I, F>
where I: Sync, F: Sync,



impl<I, F> Sync for Map<I, F>
where I: Sync, F: Sync,



impl<I, F, const N: usize> Sync for MapWindows<I, F, N>
where F: Sync, I: Sync, <I as Iterator>::Item: Sync,



impl<I, G> Sync for IntersperseWith<I, G>
where G: Sync, <I as Iterator>::Item: Sync, I: Sync,



impl<I, P> Sync for Filter<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for MapWhile<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for SkipWhile<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for TakeWhile<I, P>
where I: Sync, P: Sync,



impl<I, St, F> Sync for Scan<I, St, F>
where I: Sync, F: Sync, St: Sync,



impl<I, U, F> Sync for FlatMap<I, U, F>
where <U as IntoIterator>::IntoIter: Sync, I: Sync, F: Sync,



impl<I, const N: usize> Sync for ArrayChunks<I, N>
where I: Sync, <I as Iterator>::Item: Sync,



impl<Idx> Sync for Clamp<Idx>
where Idx: Sync,



impl<Idx> Sync for maybe_std::ops::Range<Idx>
where Idx: Sync,



impl<Idx> Sync for maybe_std::ops::RangeFrom<Idx>
where Idx: Sync,



impl<Idx> Sync for maybe_std::ops::RangeInclusive<Idx>
where Idx: Sync,



impl<Idx> Sync for RangeTo<Idx>
where Idx: Sync,



impl<Idx> Sync for maybe_std::ops::RangeToInclusive<Idx>
where Idx: Sync,



impl<Idx> Sync for maybe_std::range::Range<Idx>
where Idx: Sync,



impl<Idx> Sync for maybe_std::range::RangeFrom<Idx>
where Idx: Sync,



impl<Idx> Sync for maybe_std::range::RangeInclusive<Idx>
where Idx: Sync,



impl<Idx> Sync for maybe_std::range::RangeToInclusive<Idx>
where Idx: Sync,



impl<P> Sync for MaybeDangling<P>
where P: Sync + ?Sized,



impl<Ptr> Sync for Pin<Ptr>
where Ptr: Sync,



impl<T> Sync for Bound<T>
where T: Sync,



impl<T> Sync for Option<T>
where T: Sync,



impl<T> Sync for Poll<T>
where T: Sync,



impl<T> Sync for Reverse<T>
where T: Sync,



impl<T> Sync for NumBuffer<T>
where T: Sync,



impl<T> Sync for Pending<T>



impl<T> Sync for Ready<T>
where T: Sync,



impl<T> Sync for Empty<T>



impl<T> Sync for Once<T>
where T: Sync,



impl<T> Sync for Rev<T>
where T: Sync,



impl<T> Sync for Discriminant<T>



impl<T> Sync for ManuallyDrop<T>
where T: Sync + ?Sized,



impl<T> Sync for TraitImpl<T>
where T: ?Sized,



impl<T> Sync for Saturating<T>
where T: Sync,



impl<T> Sync for Wrapping<T>
where T: Sync,



impl<T> Sync for Yeet<T>
where T: Sync,



impl<T> Sync for AssertUnwindSafe<T>
where T: Sync,



impl<T> Sync for maybe_std::result::IntoIter<T>
where T: Sync,



impl<T> Sync for PhantomContravariant<T>
where T: ?Sized,



impl<T> Sync for PhantomCovariant<T>
where T: ?Sized,



impl<T> Sync for PhantomData<T>
where T: Sync + ?Sized,



impl<T> Sync for PhantomInvariant<T>
where T: ?Sized,



impl<T> Sync for MaybeUninit<T>
where T: Sync,



impl<T, E> Sync for Result<T, E>
where T: Sync, E: Sync,



impl<T, F> Sync for Successors<T, F>
where F: Sync, T: Sync,



impl<T, F> Sync for DropGuard<T, F>
where T: Sync, F: Sync,



impl<T, const N: usize> Sync for maybe_std::array::IntoIter<T, N>
where T: Sync,



impl<T, const N: usize> Sync for Mask<T, N>
where T: Sync,



impl<T, const N: usize> Sync for Simd<T, N>
where T: Sync,



impl<Y, R> Sync for CoroutineState<Y, R>
where Y: Sync, R: Sync,